@@ -93,8 +93,7 @@ test.workbook.writeAndReadWorksheet <- function() {
 	cdf <- data.frame(
 			"Column.A" = c(1, 2, 3, NA, 5, 6, 7, 8, NA, 10),
 			"Column.B" = c(-4, -3, NA, -1, 0, NA, NA, 3, 4, 5),
-			"Column.C" = c("Anna", "", 
-					NA, "", NA, "$!?&%", "(2@~'^*#|)", "{}[]:,;-_<>", "\\sadf\n\nv", "a b c"),
+			"Column.C" = c("Anna", "???", NA, "", NA, "$!?&%", "(?2@?~?'^*#|)", "{}[]:,;-_<>", "\\sadf\n\nv", "a b c"),
 			"Column.D" = c(pi, -pi, NA, sqrt(2), sqrt(0.3), -sqrt(pi), exp(1), log(2), sin(2), -tan(2)),
 			"Column.E" = c(TRUE, TRUE, NA, NA, FALSE, FALSE, TRUE, NA, FALSE, TRUE),
 			"Column.F" = c("High", "Medium", "Low", "Low", "Low", NA, NA, "Medium", "High", "High"),
@@ -117,13 +116,13 @@ test.workbook.writeAndReadWorksheet <- function() {
 	createSheet(wb.xls, "rownames")
 	writeWorksheet(wb.xls, mtcars, "rownames", startRow = 9, startCol = 10, header = TRUE, rownames = "Car")
 	res <- readWorksheet(wb.xls, "rownames", startRow = 9, startCol = 10)
-	checkEquals(includeRownames(mtcars, "Car"), res, check.attributes = FALSE, check.names = TRUE)
+	checkEquals(XLConnect:::includeRownames(mtcars, "Car"), res, check.attributes = FALSE, check.names = TRUE)
 	
 	# Check writing of data.frame with row names (*.xlsx)
 	createSheet(wb.xlsx, "rownames")
 	writeWorksheet(wb.xlsx, mtcars, "rownames", startRow = 9, startCol = 10, header = TRUE, rownames = "Car")
 	res <- readWorksheet(wb.xlsx, "rownames", startRow = 9, startCol = 10)
-	checkEquals(includeRownames(mtcars, "Car"), res, check.attributes = FALSE, check.names = TRUE)
+	checkEquals(XLConnect:::includeRownames(mtcars, "Car"), res, check.attributes = FALSE, check.names = TRUE)
 	
 	# Check writing & reading of data.frame with row names (*.xls)
 	createSheet(wb.xls, name = "rownames2")
